<?php

namespace FiloBlu\ExtAnowaveGtmEnhancedEcommerceUaTrackingEc\Helper;

use Magento\Store\Model\Store;
use Anowave\Package\Helper\Package;
use Magento\Framework\Registry;
use Anowave\Package\Helper\Base;

class Data extends \Anowave\Ec\Helper\Data {

    /**
     * Get loaded product collection from product list block 
     *  
     * @param \Magento\Catalog\Block\Product\ListProduct $list
     */
    private function getLoadedCollection(\Magento\Catalog\Block\Product\ListProduct $list) {
        $collection = $list->getLoadedProductCollection();

        /**
         * Get toolbar
         */
        $toolbar = $list->getToolbarBlock();

        if ($toolbar) {
            $orders = $list->getAvailableOrders();

            if ($orders) {
                $toolbar->setAvailableOrders($orders);
            }

            $sort = $list->getSortBy();

            if ($sort) {
                $toolbar->setDefaultOrder($sort);
            }

            $dir = $list->getDefaultDirection();

            if ($dir) {
                $toolbar->setDefaultDirection($dir);
            }

            $modes = $list->getModes();

            if ($modes) {
                $toolbar->setModes($modes);
            }

//			$collection->setCurPage($toolbar->getCurrentPage());

            $limit = (int) $toolbar->getLimit();

            if ($limit) {
//                          $collection->setPageSize($limit);
                $_categoryId = -1;

                // for avoid problems on search
                if ($this->registry->registry("current_category")) {
                    $_categoryId = $this->registry->registry("current_category")->getId();
                }

                $offset = 0;
                $page = (int) $this->request->getParam('p', 1);

                if ($page > 1) {

                    $listMode = $toolbar->getCurrentMode();
                    $productNumberPage1 = $this->_helperCategoryPagination->getProductNumber($listMode, 1, $_categoryId);
                    $productNumberPageOther = $this->_helperCategoryPagination->getProductNumber($listMode, 2, $_categoryId);

                    $offset = $productNumberPage1 + ($productNumberPageOther * ($page - 2));

                    if ($this->_helperCategoryPagination->getConfig('general/load_all_products_before') && !$this->request->isXmlHttpRequest()) {
                        $limit = $offset + $limit;
                        $offset = 0;
                    }
                }

                $collection->getSelect()->limit($limit, $offset);
            }

            if ($toolbar->getCurrentOrder()) {
                $collection->setOrder($toolbar->getCurrentOrder(), $toolbar->getCurrentDirection());
            }
        }

        return $collection;
    }

    public function getSearchPush($block) {
        try {
            $list = $block->getLayout()->getBlock('search_result_list');


            if ($list) {
                $response = array
                    (
                    'currencyCode' => $this->getStore()->getCurrentCurrencyCode(),
                    'ecommerce' => array
                        (
                        'actionField' => array
                            (
                            'list' => 'Search Results'
                        ),
                        'impressions' => array()
                    )
                );

                $position = 1;

                $data = array();

                foreach ($this->getLoadedCollection($list) as $product) {
                    $response['ecommerce']['impressions'][] = array
                        (
                        'list' => 'Search Results',
                        'category' => 'Search Results',
                        'id' => $product->getSku(),
                        'name' => $product->getName(),
                        'brand' => $this->getBrand
                                (
                                $product
                        ),
                        'price' => $this->getPrice($product),
                        'position' => $position++
                    );
                }

                $response['currentStore'] = $this->getStoreName();
            }

            return (object)
                    [
                        'push' => json_encode($response, JSON_PRETTY_PRINT),
                        'google_tag_params' => array
                            (
                            'ecomm_pagetype' => 'category',
                            'ecomm_category' => 'Search Results'
                        )
            ];
        } catch (\Exception $e) {
            
        }

        return false;
    }

}
